@@ -93,9 +93,13 @@ def _setup_locally() -> None:
 
 @d.dataclass(eq=False)
 class Toolset:
+    """Interface to the Modest Toolset."""
+
     executable: t.Union[str, pathlib.Path]
+    """Path to the executable of the Modest Toolset."""
 
     environment: t.Optional[t.Mapping[str, str]] = None
+    """Environment variables for the execution."""
 
     def check(
         self,
@@ -198,7 +202,7 @@ checker = ModestChecker(toolset)
 
 def get_checker(*, accept_license: bool) -> checkers.Checker:
     """Returns an instance of :class:`~momba.analysis.Checker`."""
-    assert accept_license, "you need to accept the liecense of the Modest Toolset"
+    assert accept_license, "you need to accept the license of the Modest Toolset"
     _setup_locally()
     toolset = Toolset(_MODEST_EXE)
     return ModestChecker(toolset)
